@@ -63,9 +63,6 @@
 # rsync: ALL
 # Setup example:
 #
-# <both server>:
-# mkdir /var/run/asnmtap/; chown /var/run/asnmtap/
-# 
 # <slave server>:
 #   ssh-keygen -q -t rsa -f /home/asnmtap/.ssh/rsync -N ""
 # or
@@ -89,17 +86,19 @@
 # /opt/asnmtap-3.000.xxx/applications/slave/rsync-mirror-failover-asnmtap.citap.be.sh
 # ------------------------------------------------------------------------------
 
-RMVersion='3.000.009'
+RMVersion='3.000.010'
 echo "rsync-mirror-distributed version $RMVersion"
 
-PidPath=/var/run/asnmtap                           # mkdir /var/run/asnmtap/; chown /var/run/asnmtap/
-KeyRsync=/home/asnmtap/.ssh/rsync                  # <-- need to be adjusted
+PidPath=/opt/asnmtap-3.000.xxx/pid/asnmtap
+
+Rsync=/usr/local/bin/rsync                        # <-- need to be adjusted
+KeyRsync=/home/asnmtap/.ssh/rsync                 # <-- need to be adjusted
 ConfFile=rsync-mirror-distributed.conf
 ConfPath=/opt/asnmtap-3.000.xxx/applications/slave
 Delete=''
-# AdditionalParams=''                              # --numeric-ids, -H, -v and -R
-Reverse=no                                         # 'yes' -> from slave to master
-                                                   # 'no'  -> from master to slave
+# AdditionalParams=''                             # --numeric-ids, -H, -v and -R
+Reverse=no                                        # 'yes' -> from slave to master
+                                                  # 'no'  -> from master to slave
 
 # ------------------------------------------------------------------------------
 # DON'T TOUCH BELOW HERE UNLESS YOU KNOW WHAT YOU ARE DOING!
@@ -171,11 +170,11 @@ Lock='yes'
   case "$Source" in
     */)
       echo Mirroring directory "$Source" to "$Target"
-      rsync -e "ssh -i $KeyRsync" -a $Delete $AdditionalParams $Source $Target
+      $Rsync -e "ssh -i $KeyRsync" -a $Delete $AdditionalParams $Source $Target
       ;;
     *)
       echo Mirroring "$Source" to "$Target"
-      rsync -e "ssh -i $KeyRsync" -a $Delete $AdditionalParams $Source $Target
+      $Rsync -e "ssh -i $KeyRsync" -a $Delete $AdditionalParams $Source $Target
       ;;
     esac
 done
